@@ -1,6 +1,6 @@
 import numpy as np
 
-from typing import List, Tuple, Optional, Type, ClassVar
+from typing import List, Tuple, Optional, Type, ClassVar, Union
 
 
 class DataPacket:
@@ -74,12 +74,12 @@ class Word:
         WORK_OF_ART: ClassVar[str] = 'WORK_OF_ART'
         EVENT: ClassVar[str] = 'EVENT'
 
-    def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: Optional[int] = None,
+    def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: Optional[Union[str, int]] = None,
                  confidence: float = 0, entity: Optional[str] = None, entity_group_id: Optional[int] = None):
         self.word: str = word
         self.start_time: float = start_time_millis
         self.end_time: float = end_time_millis
-        self.speaker: int = speaker
+        self.speaker: str = str(speaker) if speaker is not None else None
         self.confidence: float = confidence
         self.entity: Optional[str] = entity
         self.entity_group_id: Optional[int] = entity_group_id
